@@ -160,8 +160,8 @@ class SSync(object):
 					index[id] = fp.mtime(format="seconds")
 			def get_dirs(path):
 				dirs = []
-				for _, dirs, _ in os.walk(path):
-					for dir in dirs: 
+				for _, _dirs_, _ in os.walk(path):
+					for dir in _dirs_: 
 						newpath = gfp.clean(path=f"{path}/{dir}/")
 						dirs.append(newpath)
 						dirs += get_dirs(newpath)
@@ -423,23 +423,43 @@ class SSync(object):
 		def run(self):
 
 			# logs.
-			if self.log_level >= 0: print(f"Starting daemon {self.id}")
+			if self.log_level >= 0: 
+				loader = syst3m.console.Loader(f"Checking daemon {self.id}", interactive=INTERACTIVE)
 
 			# checks.
 			if "*mounted*" not in str(cache.get(id=self.path, group="daemons")):
+				if self.log_level >= 0: loader.stop(success=False)
 				self.crash(f"ssht00ls daemon ({self.id}): Path [{self.path}] is not mounted.")
-			elif not os.path.exists(self.path):
+			if self.log_level >= 0: 
+				loader.mark(f"Checking mountpoint {self.path}")
+			if not os.path.exists(self.path):
+				if self.log_level >= 0: loader.stop(success=False)
 				self.crash(f"ssht00ls daemon ({self.id}): Path [{self.path}] does not exist.")
-			elif not os.path.isdir(self.path):
+			if not os.path.isdir(self.path):
+				if self.log_level >= 0: loader.stop(success=False)
 				self.crash(f"ssht00ls daemon ({self.id}): Path [{self.path}] is not a directory.")
 
+
 			# check alias.
+			if self.log_level >= 0: 
+				loader.mark(f"Checking alias {self.alias}")
 			response = aliases.check(self.alias)
-			if not response.success: self.crash(response.error)
+			if not response.success: 
+				if self.log_level >= 0: loader.stop(success=False)
+				self.crash(response.error)
 
 			# get index.
+			if self.log_level >= 0: 
+				loader.mark(f"Indexing [{self.path}] & [{self.alias}:{self.remote}].")
 			response = self.index(short=True)
-			if not response.success: self.crash(response.error)
+			if not response.success: 
+				if self.log_level >= 0: loader.stop(success=False)
+				self.crash(response.error)
+
+			# start success.
+			if self.log_level >= 0: 
+				loader.mark(f"Starting daemon {self.id}")
+				loader.stop()
 
 			# start.
 			while True:
@@ -458,7 +478,7 @@ class SSync(object):
 				if self.log_level >= 1:
 					r3sponse.log(response=response)
 				if not response.success: 
-					self.crash(f"ssht00ls daemon ({self.id}) error: {response.error}")
+					self.crash(f"ssht00ls daemon ({self.id}) error: {response.error}", unmount=False)
 
 				# sleep.
 				time.sleep(self.sleeptime)
@@ -472,11 +492,12 @@ class SSync(object):
 			if not response["success"]: self.crash(f"ssht00ls daemon ({self.id}) error: {response['error']}")
 			cache.set(id=self.path, data="*stopped*", group="daemons")
 			if self.log_level >= 0: print(f"Stopped daemon {self.id}")
-		def crash(self, error=None, response=None):
-			response = self.unmount()
-			if not response["success"]: 
-				cache.set(id=self.path, data="*crashed*", group="daemons")
-				raise ValueError(f"ssht00ls daemon ({self.id}) error: {response['error']}")
+		def crash(self, error=None, response=None, unmount=True):
+			if unmount:
+				response = self.unmount()
+				if not response["success"]: 
+					cache.set(id=self.path, data="*crashed*", group="daemons")
+					raise ValueError(f"ssht00ls daemon ({self.id}) error: {response['error']}")
 			if response != None: error = response["error"]
 			cache.set(id=self.path, data="*crashed*", group="daemons")
 			raise ValueError(error)
