@@ -12,9 +12,9 @@ json = cl1.arguments_present(["--json", "-j"])
 
 # checks.
 if not os.path.exists(path):
-	r3sponse.log(json=json, response=r3sponse.error_response(f"Path [{path}] does not exist."))
+	r3sponse.log(response=r3sponse.error_response(f"Path [{path}] does not exist."), json=json)
 elif not os.path.isdir(path):
-	r3sponse.log(json=json, response=r3sponse.error_response(f"Path [{path}] is not a directory."))
+	r3sponse.log(response=r3sponse.error_response(f"Path [{path}] is not a directory."), json=json)
 
 # index.
 index, gfp, ids = Files.Dictionary(path=False, dictionary={}), Formats.FilePath("/"), []
@@ -27,8 +27,8 @@ for _path_ in Files.Directory(path=path).paths(recursive=True):
 		index[id] = fp.mtime(format="seconds")
 def get_dirs(path):
 	dirs = []
-	for _, dirs, _ in os.walk(path):
-		for dir in dirs: 
+	for _, _dirs_, _ in os.walk(path):
+		for dir in _dirs_: 
 			newpath = gfp.clean(path=f"{path}/{dir}/")
 			dirs.append(newpath)
 			dirs += get_dirs(newpath)
